# xfao-core

[![](https://img.shields.io/pypi/v/xfao-core.svg?label=PyPI&style=flat-square)](https://pypi.org/pypi/xfao-core/)
[![](https://img.shields.io/pypi/pyversions/xfao-core.svg?label=Python&color=yellow&style=flat-square)](https://pypi.org/pypi/xfao-core/)
[![Downloads](https://static.pepy.tech/personalized-badge/xfao-core?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=Downloads&style=flat-square)]